@@ -6,7 +6,7 @@ use crate::{
 };
 
 use core::mem::take;
-use std::{collections::VecDeque, path::PathBuf};
+use std::{collections::VecDeque, fmt::Debug};
 
 ///The struct for command information store and command execution
 ///This can be root and edge
@@ -21,7 +21,7 @@ pub struct Command {
 	pub authors: String,
 	///Command copyright
 	pub copyright: String,
-	/// license of command
+	/// License of command
 	pub license: License,
 	/// Command description
 	pub description: Option<String>,
@@ -70,7 +70,7 @@ macro_rules! sub_check_field {
 		}
 	};
 	($context:expr,$context_field:ident,$sub:expr, $self:expr, $field:ident :License) => {
-		if $sub.$field.has_info() {
+		if $sub.$field.is_some() {
 			$self.$field = $context.$context_field.take();
 			$context.$context_field = $sub.$field.take();
 		}
@@ -102,7 +102,7 @@ macro_rules! check_sub_field {
 		}
 	};
 	($sub:expr, $field:ident :License, $self:expr) => {
-		if $sub.$field.has_info() {
+		if $sub.$field.is_some() {
 			$sub.$field.take()
 		} else {
 			$self.$field.take()
@@ -113,54 +113,90 @@ macro_rules! check_sub_field {
 /// HelpFunc shows type alias for help function
 pub type HelpFunc = fn(command: &Command, context: &Context) -> String;
 
-/// License shows license
-#[derive(Clone, PartialEq, Eq, Debug)]
-pub enum License {
-	/// Shows no License information.
-	None,
-	/// Shows License As SPDXExpr
-	SPDXExpr(String),
-	/// Shows abstruct of license
-	Abst(String),
-	/// Shows content of license
-	Content(String),
-	/// Shows path of license file
-	File(PathBuf),
-	/// Shows abstruct of license and path of license file
-	AbstAndFile(String, PathBuf),
-	/// Shows abstruct and content of license
-	AbstAndContent(String, String),
-}
+#[derive(Clone)]
+/// License shows license information
+pub struct License(pub Option<(String, fn(ctx: &Context) -> String)>);
 
 impl Default for License {
 	fn default() -> Self {
-		License::Content(String::new())
+		License(None)
+	}
+}
+
+impl Debug for License {
+	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+		if let License(Some(val)) = self {
+			write!(f, "Some({},Func for Output)", val.0)
+		} else {
+			write!(f, "None")
+		}
 	}
 }
 
 impl License {
-	/// Replace self with License::None and returns the previous self's value.
-	pub fn take(&mut self) -> License {
-		let mut dest = License::None;
-		std::mem::swap(self, &mut dest);
-		dest
+	/// Creates new License information.
+	pub fn new(inner: Option<(String, fn(ctx: &Context) -> String)>) -> Self {
+		License(inner)
 	}
-
-	/// Returns true if self is License::None
+	/// Returns true if self has some license information.
+	pub fn is_some(&self) -> bool {
+		matches!(*self, License(Some(_)))
+	}
+	/// Returns true if self has no license information.
 	pub fn is_none(&self) -> bool {
+		matches!(*self, License(None))
+	}
+	/// Takes inner license information of self and returns.
+	pub fn take(&mut self) -> Self {
+		core::mem::take(self)
+	}
+	/// Returns (short) expression of license. If no license information(self is License(None)), returns None.
+	pub fn expr(&self) -> Option<String> {
 		match self {
-			License::None => true,
-			_ => false,
+			License(Some((expr, _))) => Some(expr.into()),
+			License(None) => None,
 		}
 	}
-
-	/// Returns true if self has license information(not License::None).
-	pub fn has_info(&self) -> bool {
+	/// Returns (short) expression of license. If no license information(self is License(None)), this function may panic.
+	pub fn expr_unwrap(&self) -> String {
 		match self {
-			License::None => false,
-			_ => true,
+			License(Some((expr, _))) => expr.clone(),
+			License(None) => panic!("called `License::expr_unwrap()` on a `None` value"),
 		}
 	}
+	/// Returns (long) expression - detail of license.
+	pub fn output(&self, ctx: &Context) -> Option<String> {
+		match self {
+			License(Some((_, outputter))) => Some(outputter(ctx)),
+			License(None) => None,
+		}
+	}
+	/// Returns (long) expression - detail of license. If self is License(None), this function may panic.
+	pub fn output_unwrap(&self, ctx: &Context) -> String {
+		match self {
+			License(Some((_, outputter))) => outputter(ctx),
+			_ => panic!("called `License::expr_unwrap()` on a `None`value"),
+		}
+	}
+	/// Returns function which outputs (long) expression (or detail of license) with wrapping Option.
+	pub fn output_fn(self) -> Option<fn(&Context) -> String> {
+		match self {
+			License(Some((_, outputter))) => Some(outputter),
+			License(None) => None,
+		}
+	}
+	/// Returns function of (long) expression (or detail of license). If self is License(None), this will panic.
+	pub fn output_fn_wrap(self) -> fn(&Context) -> String {
+		match self {
+			License(Some((_, outputter))) => outputter,
+			_ => panic!("called `License::output_fn_wrap` on a `None` value"),
+		}
+	}
+	/// Returns unwrap inner
+	pub fn unwrap(self) -> (String, fn(ctx: &Context) -> String) {
+		let License(inner) = self;
+		inner.unwrap()
+	}
 }
 
 macro_rules! gen_context_for_self_action {
@@ -257,7 +293,7 @@ impl Command {
 			action,
 			authors.into(),
 			String::default(),
-			License::None,
+			License(None),
 			Some(description.into()),
 			String::default(),
 			Vector::default(),
@@ -276,7 +312,7 @@ impl Command {
 			action: None,
 			authors: String::default(),
 			copyright: String::default(),
-			license: License::None,
+			license: License::default(),
 			description: None,
 			usage: String::default(),
 			l_flags: Vector::default(),
@@ -517,14 +553,6 @@ impl Command {
 	}
 }
 
-/*
-impl Drop for Command {
-	fn drop(&mut self) {
-		println!("drop:{}", self.name);
-	}
-}
-*/
-
 impl From<String> for Command {
 	fn from(name: String) -> Self {
 		Command {
@@ -1056,6 +1084,8 @@ impl Command {
 }
 #[cfg(test)]
 mod tests {
+	use crate::license;
+
 	use super::super::parser::ParseError;
 	use super::super::{Flag, FlagType};
 	use super::*;
@@ -1131,13 +1161,7 @@ mod tests {
 				assert_eq!(c.common_flags_values, c_flag_values);
 				assert_eq!(c.now_cmd_version, "root_version".to_owned());
 				assert_eq!(c.now_cmd_copyright, "root_copyright".to_owned());
-				assert_eq!(
-					c.now_cmd_license,
-					License::AbstAndContent(
-						String::from("root_license"),
-						String::from("root_license_content")
-					)
-				);
+				assert_eq!(c.now_cmd_license.unwrap().0, String::from("root_license"));
 				done!()
 			})
 			.common_flag(Flag::new(
@@ -1148,9 +1172,9 @@ mod tests {
 			.local_flag(Flag::new("local", FlagType::default(), "sample local flag"))
 			.version("root_version")
 			.copyright("root_copyright")
-			.license(License::AbstAndContent(
+			.license(license!(
 				"root_license".into(),
-				"root_license_content".into(),
+				content=>"root_license_content".into()
 			));
 
 		let _ = root.single_run(arg);
@@ -1166,7 +1190,7 @@ mod tests {
 			"test".to_string(),
 		];
 		let mut root = Command::new()
-			.action(|c| {
+			.action(|mut c| {
 				println!("test_action: {:?}", c);
 				let raw_args = vec![
 					"exe_path".to_string(),
@@ -1194,13 +1218,10 @@ mod tests {
 				assert_eq!(c.routes, Vector(None));
 				assert_eq!(c.now_cmd_version, "root_version".to_owned());
 				assert_eq!(c.now_cmd_copyright, "root_copyright".to_owned());
-				assert_eq!(
-					c.now_cmd_license,
-					License::AbstAndContent(
-						String::from("root_license"),
-						String::from("root_license_content")
-					)
-				);
+				let License(inner) = c.now_cmd_license.take();
+				let inner = inner.unwrap();
+				assert_eq!(inner.0, String::from("root_license"));
+				assert_eq!(inner.1(&c), String::from("root_license_content"));
 				done!()
 			})
 			.common_flag(Flag::new(
@@ -1215,9 +1236,9 @@ mod tests {
 			}))
 			.version("root_version")
 			.copyright("root_copyright")
-			.license(License::AbstAndContent(
-				"root_license".into(),
-				"root_license_content".into(),
+			.license(license!(
+				expr=>"root_license".into(),
+				content=>"root_license_content".into()
 			));
 		let _ = root.run(arg);
 	}
@@ -1231,9 +1252,9 @@ mod tests {
 			.common_flag(Flag::new_bool("cafter"))
 			.version("root_version")
 			.copyright("root_copyright")
-			.license(License::AbstAndContent(
+			.license(license!(
 				"root_license".into(),
-				"root_license_content".into(),
+				content=>"root_license_content".into(),
 			))
 			.authors("root_authors")
 	}
@@ -1245,8 +1266,11 @@ mod tests {
 			assert_eq!($context.now_cmd_version, prefix.clone() + "version");
 			assert_eq!($context.now_cmd_copyright, prefix.clone() + "copyright");
 			assert_eq!(
-				$context.now_cmd_license,
-				License::AbstAndContent(prefix.clone() + "license", prefix + "license_content")
+				(
+					$context.now_cmd_license.expr_unwrap(),
+					$context.now_cmd_license.output_unwrap(&$context)
+				),
+				(prefix.clone() + "license", prefix + "license_content")
 			);
 		};
 	}
@@ -1271,7 +1295,6 @@ mod tests {
 				);
 				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("root_", c);
-
 				done!()
 			})
 			.run(arg.clone());
@@ -1521,9 +1544,9 @@ mod tests {
 			.authors("sub_authors")
 			.version("sub_version")
 			.copyright("sub_copyright")
-			.license(License::AbstAndContent(
+			.license(license!(
 				"sub_license".into(),
-				"sub_license_content".into(),
+				content=>"sub_license_content".into(),
 			));
 		let _ = root
 			.clone()
@@ -1836,9 +1859,9 @@ mod tests {
 					})
 					.version("sub_version")
 					.copyright("sub_copyright")
-					.license(License::AbstAndContent(
+					.license(license!(
 						"sub_license".into(),
-						"root_license_content".into(),
+						content=>"root_license_content".into(),
 					))
 					.authors("sub_authors")
 					.sub_command(
@@ -1884,9 +1907,9 @@ mod tests {
 							.local_flag(Flag::new_bool("local").short_alias('l'))
 							.version("leaf_version")
 							.copyright("leaf_copyright")
-							.license(License::AbstAndContent(
+							.license(license!(
 								"leaf_license".into(),
-								"leaf_license_content".into(),
+								content=>"leaf_license_content".into(),
 							))
 							.authors("leaf_authors"),
 					),
@@ -1916,9 +1939,9 @@ mod tests {
 			.authors("leaf_authors")
 			.copyright("leaf_copyright")
 			.version("leaf_version")
-			.license(License::AbstAndContent(
+			.license(license!(
 				"leaf_license".to_owned(),
-				"leaf_license_content".to_owned(),
+				content=>"leaf_license_content".to_owned(),
 			));
 
 		let run_leaf: fn(Command, Command, Command, Action, Vec<String>) -> () =
@@ -2137,7 +2160,7 @@ mod tests {
 					c.get_flag_value_of("float"),
 					Some(FlagValue::Float(10.into()))
 				);
-				assert_eq!(c.parsing_args.unwrap(), expect_error_args);
+
 				assert_eq!(
 					c.error_info_list,
 					Vector::from(vec![(
@@ -2147,6 +2170,7 @@ mod tests {
 					)])
 				);
 				assert_attrs!("sub_", c);
+				assert_eq!(c.parsing_args.unwrap(), expect_error_args);
 				done!()
 			})
 			.local_flag(Flag::new_bool("yes").short_alias('y'))
@@ -2155,9 +2179,9 @@ mod tests {
 			.authors("sub_authors")
 			.version("sub_version")
 			.copyright("sub_copyright")
-			.license(License::AbstAndContent(
+			.license(license!(
 				"sub_license".into(),
-				"sub_license_content".into(),
+				content=>"sub_license_content".into(),
 			));
 		let mut root = Command::new()
 			.action(|c| {
@@ -2182,18 +2206,11 @@ mod tests {
 			);
 		let _ = root.run(arg.clone());
 	}
-
-	/*#[test]
-	fn help_test() {
-		let root = base_root()
-			.usage("root usage")
-			.sub_command(Command::with_name("aaa").usage("aaa usage"))
-			.sub_command(Command::with_name("bbb").usage("bbb usage"));
-	}*/
 }
 
 /// Presets of Command
 pub mod presets {
+
 	use super::{Action, Command, Context, Flag, License, Vector};
 
 	/// Preset of help function
@@ -2228,8 +2245,6 @@ pub mod presets {
 			c_flags = &vec_inner;
 		}
 
-		//どちらのフラグもある
-
 		help.push_str("Flags(If exist flags have same alias and specified by user, inputted value will be interpreted as the former flag's value): \n");
 		let head: String;
 		let common_label;
@@ -2426,8 +2441,8 @@ pub mod presets {
 	}
 
 	/// Create usage preset
-	pub fn usage<T: Into<String>>(name: T) {
-		format!("{} [SUBCOMMAND OR ARG] [OPTIONS]", name.into());
+	pub fn usage<T: Into<String>>(name: T) -> String {
+		format!("{} [SUBCOMMAND OR ARG] [OPTIONS]", name.into())
 	}
 
 	/// Create root command with base
@@ -2436,7 +2451,6 @@ pub mod presets {
 		authors: T,
 		version: T,
 		description: T,
-		license: License,
 		action: Option<Action>,
 	) -> Command {
 		Command::with_all_field(
@@ -2444,7 +2458,7 @@ pub mod presets {
 			action,
 			authors.into(),
 			String::default(),
-			license,
+			License(None),
 			Some(description.into()),
 			String::default(),
 			Vector::default(),
