@@ -4,6 +4,9 @@ macro_rules! vector {
 	() => {
 		$crate::Vector(None)
 	};
+	(None) => {
+		vector!(None)
+	};
 	($elem:expr; $n:expr)=>{
 		$crate::Vector(Some(vec![$elem,$n]))
 	};
@@ -12,6 +15,263 @@ macro_rules! vector {
 	}
 }
 
+#[macro_export]
+/// Returns char from ident
+macro_rules! char {
+	(0) => {
+		'0'
+	};
+	(1) => {
+		'1'
+	};
+	(2) => {
+		'2'
+	};
+	(3) => {
+		'3'
+	};
+	(4) => {
+		'4'
+	};
+	(5) => {
+		'5'
+	};
+	(6) => {
+		'6'
+	};
+	(7) => {
+		'7'
+	};
+	(8) => {
+		'8'
+	};
+	(9) => {
+		'9'
+	};
+	(a) => {
+		'a'
+	};
+	(b) => {
+		'b'
+	};
+	(c) => {
+		'c'
+	};
+	(d) => {
+		'd'
+	};
+	(e) => {
+		'e'
+	};
+	(f) => {
+		'f'
+	};
+	(g) => {
+		'g'
+	};
+	(h) => {
+		'h'
+	};
+	(i) => {
+		'i'
+	};
+	(j) => {
+		'j'
+	};
+	(k) => {
+		'k'
+	};
+	(l) => {
+		'l'
+	};
+	(m) => {
+		'm'
+	};
+	(n) => {
+		'n'
+	};
+	(o) => {
+		'o'
+	};
+	(p) => {
+		'p'
+	};
+	(q) => {
+		'q'
+	};
+	(r) => {
+		'r'
+	};
+	(s) => {
+		's'
+	};
+	(t) => {
+		't'
+	};
+	(u) => {
+		'u'
+	};
+	(v) => {
+		'v'
+	};
+	(w) => {
+		'w'
+	};
+	(x) => {
+		'x'
+	};
+	(y) => {
+		'y'
+	};
+	(z) => {
+		'z'
+	};
+	(A) => {
+		'A'
+	};
+	(B) => {
+		'B'
+	};
+	(C) => {
+		'C'
+	};
+	(D) => {
+		'D'
+	};
+	(E) => {
+		'E'
+	};
+	(F) => {
+		'F'
+	};
+	(G) => {
+		'G'
+	};
+	(H) => {
+		'H'
+	};
+	(I) => {
+		'I'
+	};
+	(J) => {
+		'J'
+	};
+	(K) => {
+		'K'
+	};
+	(L) => {
+		'L'
+	};
+	(M) => {
+		'M'
+	};
+	(N) => {
+		'N'
+	};
+	(O) => {
+		'O'
+	};
+	(P) => {
+		'P'
+	};
+	(Q) => {
+		'Q'
+	};
+	(R) => {
+		'R'
+	};
+	(S) => {
+		'S'
+	};
+	(T) => {
+		'T'
+	};
+	(U) => {
+		'U'
+	};
+	(V) => {
+		'V'
+	};
+	(W) => {
+		'W'
+	};
+	(X) => {
+		'X'
+	};
+	(Y) => {
+		'Y'
+	};
+	(Z) => {
+		'Z'
+	};
+	(+)=>{
+		'+'
+	};
+	(*)=>{
+		'*'
+	};
+	(@)=>{
+		'@'
+	};
+	(%)=>{
+		'%'
+	};
+	(&)=>{
+		'&'
+	};
+	($)=>{
+		'$'
+	};
+	(#)=>{
+		'#'
+	};
+	(!)=>{
+		'!'
+	};
+	(-)=>{
+		'-'
+	};
+	(=)=>{
+		'='
+	};
+	(^)=>{
+		'^'
+	};
+	(~) => {
+		'~'
+	};
+	(|)=>{
+		'|'
+	};
+	(:) => {
+		':'
+	};
+	(;) => {
+		';'
+	};
+	(_) => {
+		'_'
+	};
+	(?) => {
+		'?'
+	};
+	(<) => {
+		'<'
+	};
+	(>) => {
+		'>'
+	};
+	(.) => {
+		'.'
+	};
+	(,) => {
+		','
+	};
+	($expr:expr)=>{
+		$expr
+	};
+}
+
 #[macro_export]
 /// Checks context has help flag. If the context has help flag, return ShowHelpRequest.
 macro_rules! check_help {
@@ -209,7 +469,7 @@ macro_rules! option_wrap {
 		None
 	};
 	($inner:expr) => {
-		Some($inner)
+		Some($inner.into())
 	};
 }
 
@@ -217,7 +477,7 @@ macro_rules! option_wrap {
 /// create cmd helper with full detail
 macro_rules! cmd {
 	(
-		$name:expr=>
+		$name:ident=>
 		[
 			action=>$action:expr,
 			authors=>$authors:expr,
@@ -234,23 +494,138 @@ macro_rules! cmd {
 		]
 	) => {
 		Command::with_all_field(
-			$name,
+			String::from(stringify!($name)),
 			$crate::option_wrap!($action),
-			$authors,
-			$copyright,
+			$authors.into(),
+			$copyright.into(),
 			$license,
-			$desc,
-			$usage,
+			option_wrap!($desc),
+			$usage.into(),
 			$l_flags,
 			$c_flags,
 			$alias,
-			$ver,
+			$ver.into(),
 			$sub,
 			$help,
 		)
 	};
 }
 
+#[macro_export]
+/// Helps for creating flag.
+macro_rules! flag {
+	($name:ident=>[$type:ident$(,)?$(-$s:ident),*$(,)?$(--$long:ident),*, @$description:expr,@def $default:expr]) => {
+		Flag::with_all_field(
+			String::from(stringify!($name)),
+			String::from($description),
+			$crate::vector![$($crate::char!($s)),*],
+			$crate::vector![$(stringify!($long).to_owned()),*],
+			$crate::flag_type!($type),
+			$crate::flag_value!($type, $default),
+		);
+	};
+}
+
+#[macro_export]
+/// Gets FlagType from keyword
+macro_rules! flag_type {
+	(bool) => {
+		$crate::flag_type!(Bool)
+	};
+	(b) => {
+		flag_type!(b)
+	};
+	(int) => {
+		$crate::flag_type!(Int)
+	};
+	(i) => {
+		flag_type!(int)
+	};
+	(Integer) => {
+		flag_type!(int)
+	};
+	(integer) => {
+		flag_type!(int)
+	};
+	(float) => {
+		$crate::flag_type!(Float)
+	};
+	(f) => {
+		flag_type!(f)
+	};
+	(string) => {
+		$crate::flag_type!(String)
+	};
+	(str) => {
+		flag_type!(string)
+	};
+	(Str) => {
+		flag_type!(string)
+	};
+	($i:ident) => {
+		FlagType::$i
+	};
+}
+
+#[macro_export]
+/// Creates flag_value
+macro_rules! flag_value {
+	(bool,$val:expr) => {
+		$crate::FlagValue::Bool($val)
+	};
+	(b, $val:expr) => {
+		flag_value!(bool, $val)
+	};
+	(Bool,$val:expr) => {
+		flag_value!(bool, $val)
+	};
+	(true) => {
+		flag_value!(bool, true)
+	};
+	(false) => {
+		flag_value!(bool, false)
+	};
+	(int, $val:expr) => {
+		$crate::FlagValue::Int($val)
+	};
+	(i, $val:expr) => {
+		flag_value!(int, $val)
+	};
+	(Int, $val:expr) => {
+		flag_value!(int, $val)
+	};
+	(Integer, $val:expr) => {
+		flag_value!(int, $val)
+	};
+	(integer, $val:expr) => {
+		flag_value!(int, $val)
+	};
+	(float, $val:expr) => {
+		$crate::FlagValue::Float($val)
+	};
+	(f,$val:expr) => {
+		flag_value!(float, $val)
+	};
+	(Float, $val:expr) => {
+		flag_value!(float, $val)
+	};
+	(str, $val:expr) => {
+		$crate::FlagValue::String($val)
+	};
+	(s,$val:expr) => {
+		flag_value!(str, $val)
+	};
+	(Str, $val:expr) => {
+		flag_value!(str, $val)
+	};
+	(String, $val:expr) => {
+		flag_value!(str, $val)
+	};
+	(string, $val:expr) => {
+		flag_value!(str, $val)
+	};
+}
+
 #[macro_export]
 /// Creates function returns given string
 macro_rules! string_fn {
